==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/PaneDragEndEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
/**
 * @hidden
 */
var PaneDragEndEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneDragEndEventArgsDetail, _super);
    function PaneDragEndEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.n = this.e;
        },
        enumerable: false,
        configurable: true
    });
    PaneDragEndEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.l("sourcePane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.l("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneDragEndEventArgsDetail.$t = markType(PaneDragEndEventArgsDetail, 'PaneDragEndEventArgsDetail');
    return PaneDragEndEventArgsDetail;
}(Base));
export { PaneDragEndEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/PaneDragEndEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
/**
 * @hidden
 */
var PaneDragEndEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneDragEndEventArgsDetail, _super);
    function PaneDragEndEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    PaneDragEndEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("sourcePane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragEndEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneDragEndEventArgsDetail.$t = markType(PaneDragEndEventArgsDetail, 'PaneDragEndEventArgsDetail');
    return PaneDragEndEventArgsDetail;
}(Base));
export { PaneDragEndEventArgsDetail };
